<?php

namespace Assetdocs\Transferrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Transferrequest\Interfaces\TransferrequestRepositoryInterface;
use Assetdocs\Transferrequest\Repositories\Presenter\TransferrequestItemTransformer;

/**
 * Pubic API controller class.
 */
class TransferrequestApiController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Transferrequest\Interfaces\TransferrequestRepositoryInterface $transferrequest
     *
     * @return type
     */
    public function __construct(TransferrequestRepositoryInterface $transferrequest)
    {
        $this->middleware('api');

        $this->repository = $transferrequest;
        parent::__construct();
    }

    /**
     * Show transferrequest's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $transferrequests = $this->repository
            ->pushCriteria(new \Assetdocs\Transferrequest\Repositories\Criteria\TransferrequestPublicCriteria())
            ->setPresenter('\\Assetdocs\\Transferrequest\\Repositories\\Presenter\\TransferrequestListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $transferrequests['code'] = 2000;
        return response()->json($transferrequests)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show transferrequest.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $transferrequest = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($transferrequest)) {
            $transferrequest         = $this->itemPresenter($module, new TransferrequestItemTransformer);
            $transferrequest['code'] = 2001;
            return response()->json($transferrequest)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
