<?php

namespace Assetdocs\Transferrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Transferrequest\Interfaces\TransferrequestRepositoryInterface;

class TransferrequestController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Assetdocs\Transferrequest\Interfaces\TransferrequestRepositoryInterface $transferrequest
     *
     * @return type
     */
    public function __construct(TransferrequestRepositoryInterface $transferrequest)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $transferrequest;
        parent::__construct();
    }

    /**
     * Show transferrequest's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $transferrequests = $this->repository
            ->pushCriteria(new \Assetdocs\Transferrequest\Repositories\Criteria\TransferrequestPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('transferrequest::public.transferrequest.index', compact('transferrequests'))->render();
    }

    /**
     * Show transferrequest.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $transferrequest = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('transferrequest::public.transferrequest.show', compact('transferrequest'))->render();
    }
}
