<?php

namespace Assetdocs\Transferrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Assetdocs\Transferrequest\Http\Requests\TransferrequestUserApiRequest;
use Assetdocs\Transferrequest\Interfaces\TransferrequestRepositoryInterface;
use Assetdocs\Transferrequest\Models\Transferrequest;

/**
 * User API controller class.
 */
class TransferrequestUserApiController extends BaseController
{

    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'api';

    /**
     * Initialize transferrequest controller.
     *
     * @param type TransferrequestRepositoryInterface $transferrequest
     *
     * @return type
     */
    public function __construct(TransferrequestRepositoryInterface $transferrequest)
    {
        $this->middleware('api');
        $this->middleware('jwt.auth:api');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $transferrequest;
        parent::__construct();
    }

    /**
     * Display a list of transferrequest.
     *
     * @return json
     */
    public function index(TransferrequestUserApiRequest $request)
    {
        $transferrequests  = $this->repository
            ->pushCriteria(new \Lavalite\Transferrequest\Repositories\Criteria\TransferrequestUserCriteria())
            ->setPresenter('\\Assetdocs\\Transferrequest\\Repositories\\Presenter\\TransferrequestListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->all();
        $transferrequests['code'] = 2000;
        return response()->json($transferrequests) 
            ->setStatusCode(200, 'INDEX_SUCCESS');

    }

    /**
     * Display transferrequest.
     *
     * @param Request $request
     * @param Model   Transferrequest
     *
     * @return Json
     */
    public function show(TransferrequestUserApiRequest $request, Transferrequest $transferrequest)
    {

        if ($transferrequest->exists) {
            $transferrequest         = $transferrequest->presenter();
            $transferrequest['code'] = 2001;
            return response()->json($transferrequest)
                ->setStatusCode(200, 'SHOW_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }

    /**
     * Show the form for creating a new transferrequest.
     *
     * @param Request $request
     *
     * @return json
     */
    public function create(TransferrequestUserApiRequest $request, Transferrequest $transferrequest)
    {
        $transferrequest         = $transferrequest->presenter();
        $transferrequest['code'] = 2002;
        return response()->json($transferrequest)
            ->setStatusCode(200, 'CREATE_SUCCESS');
    }

    /**
     * Create new transferrequest.
     *
     * @param Request $request
     *
     * @return json
     */
    public function store(TransferrequestUserApiRequest $request)
    {
        try {
            $attributes             = $request->all();
            $attributes['user_id']  = user_id('admin.api');
            $transferrequest          = $this->repository->create($attributes);
            $transferrequest          = $transferrequest->presenter();
            $transferrequest['code']  = 2004;

            return response()->json($transferrequest)
                ->setStatusCode(201, 'STORE_SUCCESS');
        } catch (Exception $e) {
            return response()->json([
                'message' => $e->getMessage(),
                'code'    => 4004,
            ])->setStatusCode(400, 'STORE_ERROR');
        }

    }

    /**
     * Show transferrequest for editing.
     *
     * @param Request $request
     * @param Model   $transferrequest
     *
     * @return json
     */
    public function edit(TransferrequestUserApiRequest $request, Transferrequest $transferrequest)
    {
        if ($transferrequest->exists) {
            $transferrequest         = $transferrequest->presenter();
            $transferrequest['code'] = 2003;
            return response()-> json($transferrequest)
                ->setStatusCode(200, 'EDIT_SUCCESS');;
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }
    }

    /**
     * Update the transferrequest.
     *
     * @param Request $request
     * @param Model   $transferrequest
     *
     * @return json
     */
    public function update(TransferrequestUserApiRequest $request, Transferrequest $transferrequest)
    {
        try {

            $attributes = $request->all();

            $transferrequest->update($attributes);
            $transferrequest         = $transferrequest->presenter();
            $transferrequest['code'] = 2005;

            return response()->json($transferrequest)
                ->setStatusCode(201, 'UPDATE_SUCCESS');


        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4005,
            ])->setStatusCode(400, 'UPDATE_ERROR');

        }
    }

    /**
     * Remove the transferrequest.
     *
     * @param Request $request
     * @param Model   $transferrequest
     *
     * @return json
     */
    public function destroy(TransferrequestUserApiRequest $request, Transferrequest $transferrequest)
    {

        try {

            $t = $transferrequest->delete();

            return response()->json([
                'message'  => trans('messages.success.delete', ['Module' => trans('transferrequest::transferrequest.name')]),
                'code'     => 2006
            ])->setStatusCode(202, 'DESTROY_SUCCESS');

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 4006,
            ])->setStatusCode(400, 'DESTROY_ERROR');
        }
    }
}
