<?php

namespace Assetdocs\Transferrequest\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Assetdocs\Transferrequest\Http\Requests\TransferrequestUserWebRequest;
use Assetdocs\Transferrequest\Interfaces\TransferrequestRepositoryInterface;
use Assetdocs\Transferrequest\Models\Transferrequest;

class TransferrequestUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize transferrequest controller.
     *
     * @param type TransferrequestRepositoryInterface $transferrequest
     *
     * @return type
     */
    public function __construct(TransferrequestRepositoryInterface $transferrequest)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $transferrequest;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(TransferrequestUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Assetdocs\Transferrequest\Repositories\Criteria\TransferrequestUserCriteria());
        $transferrequests = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('transferrequest::transferrequest.names').' :: ');

        return $this->theme->of('transferrequest::user.transferrequest.index', compact('transferrequests'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Transferrequest $transferrequest
     *
     * @return Response
     */
    public function show(TransferrequestUserWebRequest $request, Transferrequest $transferrequest)
    {
        Form::populate($transferrequest);

        return $this->theme->of('transferrequest::user.transferrequest.show', compact('transferrequest'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TransferrequestUserWebRequest $request)
    {

        $transferrequest = $this->repository->newInstance([]);
        Form::populate($transferrequest);

        return $this->theme->of('transferrequest::user.transferrequest.create', compact('transferrequest'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TransferrequestUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $transferrequest = $this->repository->create($attributes);

            return redirect(trans_url('/user/transferrequest/transferrequest'))
                -> with('message', trans('messages.success.created', ['Module' => trans('transferrequest::transferrequest.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Transferrequest $transferrequest
     *
     * @return Response
     */
    public function edit(TransferrequestUserWebRequest $request, Transferrequest $transferrequest)
    {

        Form::populate($transferrequest);

        return $this->theme->of('transferrequest::user.transferrequest.edit', compact('transferrequest'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Transferrequest $transferrequest
     *
     * @return Response
     */
    public function update(TransferrequestUserWebRequest $request, Transferrequest $transferrequest)
    {
        try {
            $this->repository->update($request->all(), $transferrequest->getRouteKey());

            return redirect(trans_url('/user/transferrequest/transferrequest'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('transferrequest::transferrequest.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TransferrequestUserWebRequest $request, Transferrequest $transferrequest)
    {
        try {
            $this->repository->delete($transferrequest->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('transferrequest::transferrequest.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/transferrequest/transferrequest/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
